# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.Abstracten.Detectie import Detectie
from otlmow_model.Datatypes.DtcAfmetingBxlInM import DtcAfmetingBxlInM, DtcAfmetingBxlInMWaarden
from otlmow_model.Datatypes.DtcTijdsduur import DtcTijdsduur, DtcTijdsduurWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Detectielus(Detectie):
    """Abstracte voor een detectielus. Een detectielus is een kabel onder het wegdek die in staat is om voertuigen te detecteren teneinde de verkeersregelaar aan te sturen. Selectieve lussen zijn in staat om gecodeerde informatie door te geven van prioritaire voertuigen, niet-selectieve lussen geven informatie door van alle voertuigen die het detectie gebied passeren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Detectielus'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#IVRIComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ITSapp')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LogischePoort')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RIS')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Software')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TLCfiPoort')

        self._afmetingenBL = OTLAttribuut(field=DtcAfmetingBxlInM,
                                          naam='afmetingenBL',
                                          label='afmetingen b l',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Detectielus.afmetingenBL',
                                          definition='Afmetingen breedte x lengte van de lus.',
                                          owner=self)

        self._bewakingstijd = OTLAttribuut(field=DtcTijdsduur,
                                           naam='bewakingstijd',
                                           label='bewakingstijd',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Detectielus.bewakingstijd',
                                           definition='Wachttijd (in uren) waarna een alarm pas mag optreden.',
                                           owner=self)

    @property
    def afmetingenBL(self) -> DtcAfmetingBxlInMWaarden:
        """Afmetingen breedte x lengte van de lus."""
        return self._afmetingenBL.get_waarde()

    @afmetingenBL.setter
    def afmetingenBL(self, value):
        self._afmetingenBL.set_waarde(value, owner=self)

    @property
    def bewakingstijd(self) -> DtcTijdsduurWaarden:
        """Wachttijd (in uren) waarna een alarm pas mag optreden."""
        return self._bewakingstijd.get_waarde()

    @bewakingstijd.setter
    def bewakingstijd(self, value):
        self._bewakingstijd.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlFiguratieCodeVerschuind(KeuzelijstField):
    """Codes voor de verschuinde figuratie markering."""
    naam = 'KlFiguratieCodeVerschuind'
    label = 'Figuratie code verschuind'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlFiguratieCodeVerschuind'
    definition = 'Codes voor de verschuinde figuratie markering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlFiguratieCodeVerschuind'
    options = {
        'STOP-SmSc': KeuzelijstWaarde(invulwaarde='STOP-SmSc',
                                      label='STOP-SmSc',
                                      status='ingebruik',
                                      definitie='Een STOP markering smal en schuin.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieCodeVerschuind/STOP-SmSc'),
        'VB-B1-GRsch': KeuzelijstWaarde(invulwaarde='VB-B1-GRsch',
                                        label='VB-B1-GRsch',
                                        status='ingebruik',
                                        definitie='Een omgekeerde driehoekmarkering groot en schuin.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieCodeVerschuind/VB-B1-GRsch')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAlgMimeType(KeuzelijstField):
    """De mime types van bestanden (AWVDocument) beperkt tot mime types voor toegelaten bestandstypen."""
    naam = 'KlAlgMimeType'
    label = 'Mimetype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlAlgMimeType'
    definition = 'De mime types van bestanden (AWVDocument) beperkt tot mime types voor toegelaten bestandstypen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAlgMimeType'
    options = {
        'application-acad': KeuzelijstWaarde(invulwaarde='application-acad',
                                             label='application-acad',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-acad'),
        'application-acadmap': KeuzelijstWaarde(invulwaarde='application-acadmap',
                                                label='application-acadmap',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-acadmap'),
        'application-pdf': KeuzelijstWaarde(invulwaarde='application-pdf',
                                            label='application-pdf',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-pdf'),
        'application-rtf': KeuzelijstWaarde(invulwaarde='application-rtf',
                                            label='application-rtf',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-rtf'),
        'application-rvt': KeuzelijstWaarde(invulwaarde='application-rvt',
                                            label='application-rvt',
                                            status='ingebruik',
                                            definitie='Revit project file.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-rvt'),
        'application-vnd.openxmlformats-officedocument.spreadsheetml.sheet': KeuzelijstWaarde(invulwaarde='application-vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                                                                                              label='application-vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                                                                                              status='ingebruik',
                                                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-vnd.openxmlformats-officedocument.spreadsheetml.sheet'),
        'application-vnd.openxmlformats-officedocument.wordprocessingml.document': KeuzelijstWaarde(invulwaarde='application-vnd.openxmlformats-officedocument.wordprocessingml.document',
                                                                                                    label='application-vnd.openxmlformats-officedocument.wordprocessingml.document',
                                                                                                    status='ingebruik',
                                                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-vnd.openxmlformats-officedocument.wordprocessingml.document'),
        'application-xml': KeuzelijstWaarde(invulwaarde='application-xml',
                                            label='application-xml',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-xml'),
        'application-zip': KeuzelijstWaarde(invulwaarde='application-zip',
                                            label='application-zip',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/application-zip'),
        'image-dxf': KeuzelijstWaarde(invulwaarde='image-dxf',
                                      label='image-dxf',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/image-dxf'),
        'image-jpeg': KeuzelijstWaarde(invulwaarde='image-jpeg',
                                       label='image-jpeg',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/image-jpeg'),
        'image-svg': KeuzelijstWaarde(invulwaarde='image-svg',
                                      label='image-svg',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/image-svg'),
        'image-tiff': KeuzelijstWaarde(invulwaarde='image-tiff',
                                       label='image-tiff',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/image-tiff'),
        'text-csv': KeuzelijstWaarde(invulwaarde='text-csv',
                                     label='text-csv',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/text-csv'),
        'text-html': KeuzelijstWaarde(invulwaarde='text-html',
                                      label='text-html',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/text-html'),
        'text-rtf': KeuzelijstWaarde(invulwaarde='text-rtf',
                                     label='text-rtf',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/text-rtf'),
        'text-xml': KeuzelijstWaarde(invulwaarde='text-xml',
                                     label='text-xml',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/text-xml'),
        'video-avi': KeuzelijstWaarde(invulwaarde='video-avi',
                                      label='video-avi',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgMimeType/video-avi')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlZelfsluiterSluitkrachtnorm(KeuzelijstField):
    """Codelijst met mogelijke waarden voor de sluitkracht van een zefsluiter voor deuren, poorten etc.volgens de bestaande normering."""
    naam = 'KlZelfsluiterSluitkrachtnorm'
    label = 'Zelfsluiter sluitkrachtnorm'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlZelfsluiterSluitkrachtnorm'
    definition = 'Codelijst met mogelijke waarden voor de sluitkracht van een zefsluiter voor deuren, poorten etc.volgens de bestaande normering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlZelfsluiterSluitkrachtnorm'
    options = {
        'en-2': KeuzelijstWaarde(invulwaarde='en-2',
                                 label='EN 2',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZelfsluiterSluitkrachtnorm/en-2'),
        'en-4': KeuzelijstWaarde(invulwaarde='en-4',
                                 label='EN 4',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZelfsluiterSluitkrachtnorm/en-4'),
        'en-6': KeuzelijstWaarde(invulwaarde='en-6',
                                 label='EN 6',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZelfsluiterSluitkrachtnorm/en-6')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Verlichtingstoestel import Verlichtingstoestel
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerlichtingstoestelTL(Verlichtingstoestel):
    """Het geheel van de TL-lamp en de behuizing die werden samengesteld met als doel:* de lichtstroom van de lichtbronnen hoofdzakelijk op het te verlichten oppervlak (doorlopende wegsectie, conflictgebied,...) te richten, teneinde de zichtbaarheid te verhogen;* de lichtstroom te beheersen zodat de weggebruikers niet verblind worden en de lichthinder beperkt wordt;* het optisch systeem, de lichtbronnen en de hulpapparatuur tegen uitwendige invloeden te beschermen"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelTL'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMDraagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring')

        self._lichtpuntHoogte = OTLAttribuut(field=KwantWrdInMeter,
                                             naam='lichtpuntHoogte',
                                             label='lichtpunt hoogte',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelTL.lichtpuntHoogte',
                                             definition='Hoogte van het lichtpunt ten opzichte van de rijweg.',
                                             owner=self)

    @property
    def lichtpuntHoogte(self) -> KwantWrdInMeterWaarden:
        """Hoogte van het lichtpunt ten opzichte van de rijweg."""
        return self._lichtpuntHoogte.get_waarde()

    @lichtpuntHoogte.setter
    def lichtpuntHoogte(self, value):
        self._lichtpuntHoogte.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.KlGraadVanBeweegbaarheid import KlGraadVanBeweegbaarheid
from otlmow_model.Datatypes.KlGraadVanStatischeBepaaldheid import KlGraadVanStatischeBepaaldheid
from otlmow_model.Datatypes.KlMateriaalDragendeStructuurBrugdeel import KlMateriaalDragendeStructuurBrugdeel
from otlmow_model.Datatypes.KlTypeBeweegbaarBrugdeel import KlTypeBeweegbaarBrugdeel
from otlmow_model.Datatypes.KlTypeBrugdeel import KlTypeBrugdeel
from otlmow_model.Datatypes.KwantWrdInKiloNewton import KwantWrdInKiloNewton, KwantWrdInKiloNewtonWaarden
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden
from otlmow_model.BaseClasses.NonNegIntegerField import NonNegIntegerField
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Brugdeel(AIMNaamObject, VlakGeometrie):
    """Het deel dat je kan wegnemen van een brug in zijn geheel. Dit kan ook meerdere overspanningen hebben."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorighedenBrug')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trillingsvoorziening')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brug')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Oplegrij')

        self._aantalOverspanningen = OTLAttribuut(field=NonNegIntegerField,
                                                  naam='aantalOverspanningen',
                                                  label='aantal overspanningen',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.aantalOverspanningen',
                                                  definition='Aantal overspanningen, van oplegging naar volgende oplegging (bij een isostatisch brugdeel zal dit één overspanning zijn, bij een hyperstatisch brugdeel zijn dit er meerdere).',
                                                  owner=self)

        self._graadVanBeweegbaarheid = OTLAttribuut(field=KlGraadVanBeweegbaarheid,
                                                    naam='graadVanBeweegbaarheid',
                                                    label='graad van beweegbaarheid',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.graadVanBeweegbaarheid',
                                                    definition='De manier waarop het brugdeel beweegt.',
                                                    owner=self)

        self._graadVanStatischeBepaaldheid = OTLAttribuut(field=KlGraadVanStatischeBepaaldheid,
                                                          naam='graadVanStatischeBepaaldheid',
                                                          label='graad van statische bepaaldheid',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.graadVanStatischeBepaaldheid',
                                                          definition='Welke statische bepaaldheid het brugdeel heeft.',
                                                          owner=self)

        self._heeftVoorzieningNegatieveReactie = OTLAttribuut(field=BooleanField,
                                                              naam='heeftVoorzieningNegatieveReactie',
                                                              label='heeft voorziening negatieve reactie',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.heeftVoorzieningNegatieveReactie',
                                                              definition='Geeft aan of het brugdeel een voorziening negatieve reactie bevat, al dan niet.',
                                                              owner=self)

        self._individueleAfstandOverspanningen = OTLAttribuut(field=KwantWrdInMeter,
                                                              naam='individueleAfstandOverspanningen',
                                                              label='individuele afstand overspanningen',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.individueleAfstandOverspanningen',
                                                              kardinaliteit_max='*',
                                                              definition='De individuele afstand tussen opeenvolgende opleggingen, in meter. Dit wordt uitgedrukt gaande van LO naar RO, of in oplopende kilometerpunten. Er kunnen meerdere waarden mogelijk zijn (vb.: voor hyperstatische brugdelen).',
                                                              owner=self)

        self._materiaalDragendeStructuur = OTLAttribuut(field=KlMateriaalDragendeStructuurBrugdeel,
                                                        naam='materiaalDragendeStructuur',
                                                        label='materiaal dragende structuur',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.materiaalDragendeStructuur',
                                                        definition='Het materiaal van de dragende structuur van het brugdeel.',
                                                        owner=self)

        self._totaleBreedteBrugdeel = OTLAttribuut(field=KwantWrdInMeter,
                                                   naam='totaleBreedteBrugdeel',
                                                   label='totale breedte brugdeel',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleBreedteBrugdeel',
                                                   definition='De totale breedte van het brugdeel, uitgedrukt in meter.',
                                                   owner=self)

        self._totaleLengteBrugdeel = OTLAttribuut(field=KwantWrdInMeter,
                                                  naam='totaleLengteBrugdeel',
                                                  label='totale lengte brugdeel',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleLengteBrugdeel',
                                                  definition='De totale lengte van voeg tot voeg van het brugdeel, uitgedrukt in meter.',
                                                  owner=self)

        self._totaleOppervlakteBrugdeel = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                                       naam='totaleOppervlakteBrugdeel',
                                                       label='totale oppervlakte brugdeel',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleOppervlakteBrugdeel',
                                                       definition='De totale oppervlakte van het gehele brugdeel (van hetzelfde type), uitgedrukt in vierkante meter.',
                                                       owner=self)

        self._totaleSpankracht = OTLAttribuut(field=KwantWrdInKiloNewton,
                                              naam='totaleSpankracht',
                                              label='totale spankracht',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.totaleSpankracht',
                                              definition='De totale spankracht van het brugdeel, uitgedrukt in kiloNewton.',
                                              owner=self)

        self._typeBeweegbaarBrugdeel = OTLAttribuut(field=KlTypeBeweegbaarBrugdeel,
                                                    naam='typeBeweegbaarBrugdeel',
                                                    label='type beweegbaar brugdeel',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.typeBeweegbaarBrugdeel',
                                                    definition='Het type van het beweegbaar brugdeel.',
                                                    owner=self)

        self._typeBrugdeel = OTLAttribuut(field=KlTypeBrugdeel,
                                          naam='typeBrugdeel',
                                          label='type brugdeel',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel.typeBrugdeel',
                                          definition='Het type brugdeel.',
                                          owner=self)

    @property
    def aantalOverspanningen(self) -> int:
        """Aantal overspanningen, van oplegging naar volgende oplegging (bij een isostatisch brugdeel zal dit één overspanning zijn, bij een hyperstatisch brugdeel zijn dit er meerdere)."""
        return self._aantalOverspanningen.get_waarde()

    @aantalOverspanningen.setter
    def aantalOverspanningen(self, value):
        self._aantalOverspanningen.set_waarde(value, owner=self)

    @property
    def graadVanBeweegbaarheid(self) -> str:
        """De manier waarop het brugdeel beweegt."""
        return self._graadVanBeweegbaarheid.get_waarde()

    @graadVanBeweegbaarheid.setter
    def graadVanBeweegbaarheid(self, value):
        self._graadVanBeweegbaarheid.set_waarde(value, owner=self)

    @property
    def graadVanStatischeBepaaldheid(self) -> str:
        """Welke statische bepaaldheid het brugdeel heeft."""
        return self._graadVanStatischeBepaaldheid.get_waarde()

    @graadVanStatischeBepaaldheid.setter
    def graadVanStatischeBepaaldheid(self, value):
        self._graadVanStatischeBepaaldheid.set_waarde(value, owner=self)

    @property
    def heeftVoorzieningNegatieveReactie(self) -> bool:
        """Geeft aan of het brugdeel een voorziening negatieve reactie bevat, al dan niet."""
        return self._heeftVoorzieningNegatieveReactie.get_waarde()

    @heeftVoorzieningNegatieveReactie.setter
    def heeftVoorzieningNegatieveReactie(self, value):
        self._heeftVoorzieningNegatieveReactie.set_waarde(value, owner=self)

    @property
    def individueleAfstandOverspanningen(self) -> List[KwantWrdInMeterWaarden]:
        """De individuele afstand tussen opeenvolgende opleggingen, in meter. Dit wordt uitgedrukt gaande van LO naar RO, of in oplopende kilometerpunten. Er kunnen meerdere waarden mogelijk zijn (vb.: voor hyperstatische brugdelen)."""
        return self._individueleAfstandOverspanningen.get_waarde()

    @individueleAfstandOverspanningen.setter
    def individueleAfstandOverspanningen(self, value):
        self._individueleAfstandOverspanningen.set_waarde(value, owner=self)

    @property
    def materiaalDragendeStructuur(self) -> str:
        """Het materiaal van de dragende structuur van het brugdeel."""
        return self._materiaalDragendeStructuur.get_waarde()

    @materiaalDragendeStructuur.setter
    def materiaalDragendeStructuur(self, value):
        self._materiaalDragendeStructuur.set_waarde(value, owner=self)

    @property
    def totaleBreedteBrugdeel(self) -> KwantWrdInMeterWaarden:
        """De totale breedte van het brugdeel, uitgedrukt in meter."""
        return self._totaleBreedteBrugdeel.get_waarde()

    @totaleBreedteBrugdeel.setter
    def totaleBreedteBrugdeel(self, value):
        self._totaleBreedteBrugdeel.set_waarde(value, owner=self)

    @property
    def totaleLengteBrugdeel(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van voeg tot voeg van het brugdeel, uitgedrukt in meter."""
        return self._totaleLengteBrugdeel.get_waarde()

    @totaleLengteBrugdeel.setter
    def totaleLengteBrugdeel(self, value):
        self._totaleLengteBrugdeel.set_waarde(value, owner=self)

    @property
    def totaleOppervlakteBrugdeel(self) -> KwantWrdInVierkanteMeterWaarden:
        """De totale oppervlakte van het gehele brugdeel (van hetzelfde type), uitgedrukt in vierkante meter."""
        return self._totaleOppervlakteBrugdeel.get_waarde()

    @totaleOppervlakteBrugdeel.setter
    def totaleOppervlakteBrugdeel(self, value):
        self._totaleOppervlakteBrugdeel.set_waarde(value, owner=self)

    @property
    def totaleSpankracht(self) -> KwantWrdInKiloNewtonWaarden:
        """De totale spankracht van het brugdeel, uitgedrukt in kiloNewton."""
        return self._totaleSpankracht.get_waarde()

    @totaleSpankracht.setter
    def totaleSpankracht(self, value):
        self._totaleSpankracht.set_waarde(value, owner=self)

    @property
    def typeBeweegbaarBrugdeel(self) -> str:
        """Het type van het beweegbaar brugdeel."""
        return self._typeBeweegbaarBrugdeel.get_waarde()

    @typeBeweegbaarBrugdeel.setter
    def typeBeweegbaarBrugdeel(self, value):
        self._typeBeweegbaarBrugdeel.set_waarde(value, owner=self)

    @property
    def typeBrugdeel(self) -> str:
        """Het type brugdeel."""
        return self._typeBrugdeel.get_waarde()

    @typeBrugdeel.setter
    def typeBrugdeel(self, value):
        self._typeBrugdeel.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEWatergreppelType(KeuzelijstField):
    """Types van watergreppel."""
    naam = 'KlLEWatergreppelType'
    label = 'Watergreppel type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEWatergreppelType'
    definition = 'Types van watergreppel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEWatergreppelType'
    options = {
        'type-II-A-2': KeuzelijstWaarde(invulwaarde='type-II-A-2',
                                        label='type II A 2',
                                        status='ingebruik',
                                        definitie='type II A 2',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEWatergreppelType/type-II-A-2'),
        'type-II-B-2': KeuzelijstWaarde(invulwaarde='type-II-B-2',
                                        label='type II B 2',
                                        status='ingebruik',
                                        definitie='type II B 2',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEWatergreppelType/type-II-B-2'),
        'type-II-C-2': KeuzelijstWaarde(invulwaarde='type-II-C-2',
                                        label='type II C 2',
                                        status='ingebruik',
                                        definitie='type II C 2',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEWatergreppelType/type-II-C-2'),
        'type-II-D-2': KeuzelijstWaarde(invulwaarde='type-II-D-2',
                                        label='type II D 2',
                                        status='ingebruik',
                                        definitie='type II D 2',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEWatergreppelType/type-II-D-2'),
        'type-II-E-2': KeuzelijstWaarde(invulwaarde='type-II-E-2',
                                        label='type II E 2',
                                        status='ingebruik',
                                        definitie='type II E 2',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEWatergreppelType/type-II-E-2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Straatmeubilair import Straatmeubilair
from otlmow_model.Datatypes.KlKleurPlooibaken import KlKleurPlooibaken
from otlmow_model.Datatypes.KlPlooibakenType import KlPlooibakenType
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Plooibaken(Straatmeubilair, PuntGeometrie):
    """Een zacht kunststoffen paal met verschillende diameter en reflecterende banden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Plooibaken'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Straatmeubilair.__init__(self)
        PuntGeometrie.__init__(self)

        self._kleur = OTLAttribuut(field=KlKleurPlooibaken,
                                   naam='kleur',
                                   label='kleur',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Plooibaken.kleur',
                                   definition='Bepaling van de kleur van het plooibaken.',
                                   owner=self)

        self._type = OTLAttribuut(field=KlPlooibakenType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Plooibaken.type',
                                  definition='De diameter en vorm van het plooibaken.',
                                  owner=self)

    @property
    def kleur(self) -> str:
        """Bepaling van de kleur van het plooibaken."""
        return self._kleur.get_waarde()

    @kleur.setter
    def kleur(self, value):
        self._kleur.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """De diameter en vorm van het plooibaken."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNeerslagsensorType(KeuzelijstField):
    """Het type van de neerslagsensor."""
    naam = 'KlNeerslagsensorType'
    label = 'Neerslagsensor type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNeerslagsensorType'
    definition = 'Het type van de neerslagsensor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNeerslagsensorType'
    options = {
        'optisch': KeuzelijstWaarde(invulwaarde='optisch',
                                    label='optisch',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorType/optisch'),
        'radar': KeuzelijstWaarde(invulwaarde='radar',
                                  label='radar',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNeerslagsensorType/radar')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlEindbeeldOpgaandeBoom(KeuzelijstField):
    """Het nagestreefde beeld van de volgroeide boom of struik op deze specifieke standplaats."""
    naam = 'KlEindbeeldOpgaandeBoom'
    label = 'Eindbeeld opgaande boom'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlEindbeeldOpgaandeBoom'
    definition = 'Het nagestreefde beeld van de volgroeide boom of struik op deze specifieke standplaats.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlEindbeeldOpgaandeBoom'
    options = {
        'gekandelaarde-boom': KeuzelijstWaarde(invulwaarde='gekandelaarde-boom',
                                               label='gekandelaarde boom',
                                               status='ingebruik',
                                               definitie='Het eindbeeld is een gekandelaarde boom. Een gekandelaarde boom is een boom waarvan alle gesteltakken periodiek op een bepaalde lengte worden afgezet en die hierop opnieuw uitlopen.',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEindbeeldOpgaandeBoom/gekandelaarde-boom'),
        'geschoren-boom': KeuzelijstWaarde(invulwaarde='geschoren-boom',
                                           label='geschoren boom',
                                           status='ingebruik',
                                           definitie='Het eindbeeld is een geschoren boom.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEindbeeldOpgaandeBoom/geschoren-boom'),
        'knotboom': KeuzelijstWaarde(invulwaarde='knotboom',
                                     label='knotboom',
                                     status='ingebruik',
                                     definitie='Het eindbeeld is een knotboom. Dit is een snoeivorm waarbij periodiek alle takken afgezaagd worden tot op een verdikte knot bovenaan de stam.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEindbeeldOpgaandeBoom/knotboom'),
        'leiboom': KeuzelijstWaarde(invulwaarde='leiboom',
                                    label='leiboom',
                                    status='ingebruik',
                                    definitie='Het eindbeeld is een leiboom. Een leiboom is een boom waarvan alle gesteltakken gedwongen worden in één (verticaal) vlak te groeien door geleiding. Soms worden de geleide bomen tegen een muur geleid of wordt er in een leidconstructie voorzien. ',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEindbeeldOpgaandeBoom/leiboom'),
        'niet-vrij-uitgroeiend': KeuzelijstWaarde(invulwaarde='niet-vrij-uitgroeiend',
                                                  label='niet vrij uitgroeiend',
                                                  status='ingebruik',
                                                  definitie='Het eindbeeld is een boom die niet vrij kan uitgroeien.',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEindbeeldOpgaandeBoom/niet-vrij-uitgroeiend'),
        'vrij-uitgroeiend': KeuzelijstWaarde(invulwaarde='vrij-uitgroeiend',
                                             label='vrij uitgroeiend',
                                             status='ingebruik',
                                             definitie='Het eindbeeld is een boom die vrij kan uitgroeien.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEindbeeldOpgaandeBoom/vrij-uitgroeiend')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.KlTypeSpankabel import KlTypeSpankabel
from otlmow_model.Datatypes.KwantWrdInVierkanteMillimeter import KwantWrdInVierkanteMillimeter, KwantWrdInVierkanteMillimeterWaarden
from otlmow_model.BaseClasses.NonNegIntegerField import NonNegIntegerField
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Spankabel(AIMNaamObject, LijnGeometrie):
    """Een kabel die gebruikt kan worden als externe naspanning of als wapening."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spankabel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        LijnGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#ExterneNaspanning')

        self._aantalDradenStrengen = OTLAttribuut(field=NonNegIntegerField,
                                                  naam='aantalDradenStrengen',
                                                  label='aantal draden of strengen',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spankabel.aantalDradenStrengen',
                                                  definition='Het aantal draden of strengen die de kabel bevat.',
                                                  owner=self)

        self._doorsnedeDradenStrengen = OTLAttribuut(field=KwantWrdInVierkanteMillimeter,
                                                     naam='doorsnedeDradenStrengen',
                                                     label='doorsnede draden of strengen',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spankabel.doorsnedeDradenStrengen',
                                                     definition='De doorsnede van de draden of strengen in de kabel, uitgedrukt in vierkante millimeter.',
                                                     owner=self)

        self._totaleSectieSpankabel = OTLAttribuut(field=KwantWrdInVierkanteMillimeter,
                                                   naam='totaleSectieSpankabel',
                                                   label='totale sectie spankabel',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spankabel.totaleSectieSpankabel',
                                                   definition='De doorsnede van de gehele spankabel, uitgedrukt in vierkante millimeter.',
                                                   owner=self)

        self._typeKabel = OTLAttribuut(field=KlTypeSpankabel,
                                       naam='typeKabel',
                                       label='type kabel',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spankabel.typeKabel',
                                       definition='Het type waaruit de spankabel is opgebouwd.',
                                       owner=self)

    @property
    def aantalDradenStrengen(self) -> int:
        """Het aantal draden of strengen die de kabel bevat."""
        return self._aantalDradenStrengen.get_waarde()

    @aantalDradenStrengen.setter
    def aantalDradenStrengen(self, value):
        self._aantalDradenStrengen.set_waarde(value, owner=self)

    @property
    def doorsnedeDradenStrengen(self) -> KwantWrdInVierkanteMillimeterWaarden:
        """De doorsnede van de draden of strengen in de kabel, uitgedrukt in vierkante millimeter."""
        return self._doorsnedeDradenStrengen.get_waarde()

    @doorsnedeDradenStrengen.setter
    def doorsnedeDradenStrengen(self, value):
        self._doorsnedeDradenStrengen.set_waarde(value, owner=self)

    @property
    def totaleSectieSpankabel(self) -> KwantWrdInVierkanteMillimeterWaarden:
        """De doorsnede van de gehele spankabel, uitgedrukt in vierkante millimeter."""
        return self._totaleSectieSpankabel.get_waarde()

    @totaleSectieSpankabel.setter
    def totaleSectieSpankabel(self, value):
        self._totaleSectieSpankabel.set_waarde(value, owner=self)

    @property
    def typeKabel(self) -> str:
        """Het type waaruit de spankabel is opgebouwd."""
        return self._typeKabel.get_waarde()

    @typeKabel.setter
    def typeKabel(self, value):
        self._typeKabel.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KLLuidsprekerVormgeving import KLLuidsprekerVormgeving
from otlmow_model.Datatypes.KlAudioTransportType import KlAudioTransportType
from otlmow_model.Datatypes.KlLuidsprekerMerk import KlLuidsprekerMerk
from otlmow_model.Datatypes.KlLuidsprekerModelnaam import KlLuidsprekerModelnaam
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Luidspreker(AIMNaamObject, PuntGeometrie):
    """Een luidspreker is een apparaat waarmee elektrische signalen worden omgezet in geluid."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Draagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Zoutbijlaadplaats')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Audioversterker')

        self._merk = OTLAttribuut(field=KlLuidsprekerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker.merk',
                                  definition='Het merk van de luidspreker.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlLuidsprekerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker.modelnaam',
                                       definition='De modelnaam van de luidspreker.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker.technischeFiche',
                                             definition='De technische fiche van de luidspreker.',
                                             owner=self)

        self._transportType = OTLAttribuut(field=KlAudioTransportType,
                                           naam='transportType',
                                           label='transport type',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker.transportType',
                                           definition='Geeft aan op welke manier het audiosignaal wordt getransporteerd door het toestel.',
                                           owner=self)

        self._vormgeving = OTLAttribuut(field=KLLuidsprekerVormgeving,
                                        naam='vormgeving',
                                        label='vormgeving',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker.vormgeving',
                                        definition='Soort luidsprekers volgens zijn vormfactor.',
                                        owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de luidspreker."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de luidspreker."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de luidspreker."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def transportType(self) -> str:
        """Geeft aan op welke manier het audiosignaal wordt getransporteerd door het toestel."""
        return self._transportType.get_waarde()

    @transportType.setter
    def transportType(self, value):
        self._transportType.set_waarde(value, owner=self)

    @property
    def vormgeving(self) -> str:
        """Soort luidsprekers volgens zijn vormfactor."""
        return self._vormgeving.get_waarde()

    @vormgeving.setter
    def vormgeving(self, value):
        self._vormgeving.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Onderdeel.BetonnenConstructieObject import BetonnenConstructieObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlTypeBetonnenProfiel import KlTypeBetonnenProfiel
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class BetonnenProfiel(BetonnenConstructieObject, LijnGeometrie):
    """Betonnen enkelvoudig constructie-element waarvan de lengte vele malen groter is dan de breedte en de hoogte in doorsnede. De breedte is weer gelijk of kleiner dan de hoogte."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenProfiel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        BetonnenConstructieObject.__init__(self)
        LijnGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')

        self._detailDwarsdoorsnede = OTLAttribuut(field=DtcDocument,
                                                  naam='detailDwarsdoorsnede',
                                                  label='detail dwarsdoorsnede',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenProfiel.detailDwarsdoorsnede',
                                                  definition='Details van de afmetingen en van de dwarsdoorsnedes.',
                                                  owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenProfiel.lengte',
                                    definition='De lengte, in lopende meter, van het profiel.',
                                    owner=self)

        self._typeProfiel = OTLAttribuut(field=KlTypeBetonnenProfiel,
                                         naam='typeProfiel',
                                         label='type profiel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenProfiel.typeProfiel',
                                         definition='Het type betonnen profiel.',
                                         owner=self)

    @property
    def detailDwarsdoorsnede(self) -> DtcDocumentWaarden:
        """Details van de afmetingen en van de dwarsdoorsnedes."""
        return self._detailDwarsdoorsnede.get_waarde()

    @detailDwarsdoorsnede.setter
    def detailDwarsdoorsnede(self, value):
        self._detailDwarsdoorsnede.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte, in lopende meter, van het profiel."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def typeProfiel(self) -> str:
        """Het type betonnen profiel."""
        return self._typeProfiel.get_waarde()

    @typeProfiel.setter
    def typeProfiel(self, value):
        self._typeProfiel.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEMarkeringSoort(KeuzelijstField):
    """Mogelijke markeringsoorten op een lijvormig element."""
    naam = 'KlLEMarkeringSoort'
    label = 'Soort markering van lijnvormig element'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEMarkeringSoort'
    definition = 'Mogelijke markeringsoorten op een lijvormig element.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEMarkeringSoort'
    options = {
        'biggenrug': KeuzelijstWaarde(invulwaarde='biggenrug',
                                      label='biggenrug',
                                      status='ingebruik',
                                      definitie='Een betonnen obstakel dat meestal een infrastructurele en beschermende functie heeft',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEMarkeringSoort/biggenrug'),
        'boordsteen': KeuzelijstWaarde(invulwaarde='boordsteen',
                                       label='boordsteen',
                                       status='ingebruik',
                                       definitie='Een lijnvormig element dat de scheiding verzorgt tussen een rijbaan en het meestal hoger gelegen trottoir',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEMarkeringSoort/boordsteen'),
        'boordsteen-parkeerverbod': KeuzelijstWaarde(invulwaarde='boordsteen-parkeerverbod',
                                                     label='boordsteen parkeerverbod',
                                                     status='ingebruik',
                                                     definitie='Een lijnvormig element dat de scheiding verzorgt tussen een rijbaan en het meestal hoger gelegen trottoir met als functie het aanduiden van parkeerverbod',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEMarkeringSoort/boordsteen-parkeerverbod'),
        'new-Jersey': KeuzelijstWaarde(invulwaarde='new-Jersey',
                                       label='new Jersey',
                                       status='ingebruik',
                                       definitie='Een afschermende constructie uit kunststof, beton of metaal dat naast wegen wordt geplaatst om te voorkomen dat voertuigen de weg in zijdelingse richting verlaten, kantelen of de middenberm doorkruisen.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEMarkeringSoort/new-Jersey'),
        'vangrail': KeuzelijstWaarde(invulwaarde='vangrail',
                                     label='vangrail',
                                     status='ingebruik',
                                     definitie='Een afschermende constructie die naast wegen wordt geplaatst om te voorkomen dat voertuigen de weg in zijdelingse richting verlaten, kantelen of de middenberm doorkruisen.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEMarkeringSoort/vangrail')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Flitsgroep(NaampadObject, VlakGeometrie):
    """Groepering om de flitspalen van een kruispunt of bepaalde zone in onder te brengen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitsgroep'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        NaampadObject.__init__(self)
        VlakGeometrie.__init__(self)

        self._isRoodLicht = OTLAttribuut(field=BooleanField,
                                         naam='isRoodLicht',
                                         label='is rood licht',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Flitsgroep.isRoodLicht',
                                         definition='Duidt aan of de groepering een snelheids- of roodlichtcamera installatie betreft.',
                                         owner=self)

    @property
    def isRoodLicht(self) -> bool:
        """Duidt aan of de groepering een snelheids- of roodlichtcamera installatie betreft."""
        return self._isRoodLicht.get_waarde()

    @isRoodLicht.setter
    def isRoodLicht(self, value):
        self._isRoodLicht.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVGOpstelling(KeuzelijstField):
    """Beschrijft de oriëntatie van het geplaatste schermelement tov de weg. De oriëntatie van vlakke schermen kan naast loodrecht op het maaiveld ook schuin naar achter hellend of schuin naar voor hellend zijn."""
    naam = 'KlVGOpstelling'
    label = 'Vlak geluidschermelement opstelling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVGOpstelling'
    definition = 'Beschrijft de oriëntatie van het geplaatste schermelement tov de weg. De oriëntatie van vlakke schermen kan naast loodrecht op het maaiveld ook schuin naar achter hellend of schuin naar voor hellend zijn.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVGOpstelling'
    options = {
        'gebogen': KeuzelijstWaarde(invulwaarde='gebogen',
                                    label='gebogen',
                                    status='ingebruik',
                                    definitie='Gebogen',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/gebogen'),
        'loodrecht-op-maaiveld': KeuzelijstWaarde(invulwaarde='loodrecht-op-maaiveld',
                                                  label='loodrecht op maaiveld',
                                                  status='ingebruik',
                                                  definitie='loodrecht op maaiveld',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/loodrecht-op-maaiveld'),
        'schuin-naar-achter-hellend': KeuzelijstWaarde(invulwaarde='schuin-naar-achter-hellend',
                                                       label='schuin naar achter hellend',
                                                       status='ingebruik',
                                                       definitie='schuin naar achter hellend t.o.v. de weg',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/schuin-naar-achter-hellend'),
        'schuin-naar-voor-hellend': KeuzelijstWaarde(invulwaarde='schuin-naar-voor-hellend',
                                                     label='schuin naar voor hellend',
                                                     status='ingebruik',
                                                     definitie='schuin naar voor hellend t.o.v. de weg',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/schuin-naar-voor-hellend'),
        'taludvorm': KeuzelijstWaarde(invulwaarde='taludvorm',
                                      label='taludvorm',
                                      status='ingebruik',
                                      definitie='Taludvorm',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/taludvorm'),
        'taludvorm---vertikaal': KeuzelijstWaarde(invulwaarde='taludvorm---vertikaal',
                                                  label='taludvorm + vertikaal',
                                                  status='ingebruik',
                                                  definitie='Taludvorm + vertikaal',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/taludvorm---vertikaal'),
        'verticaal': KeuzelijstWaarde(invulwaarde='verticaal',
                                      label='verticaal',
                                      status='ingebruik',
                                      definitie='Verticaal',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVGOpstelling/verticaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.Classes.Onderdeel.Grasland import Grasland


# Generated with OTLClassCreator. To modify: extend, do not edit
class DominantGraslandfase2(Grasland):
    """G2 - Meer dan 50% van de oppervlakte ingenomen door één niet sterk glanzende grassoort:gestreepte witbol, grote vossenstaart of glanshaver, + grassen en kruiden uit G0 en G1."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DominantGraslandfase2'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLetterCijfer(KeuzelijstField):
    """De mogelijke letters en cijfers voor een letter- of cijfermarkering."""
    naam = 'KlLetterCijfer'
    label = 'Letter-cijfer'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLetterCijfer'
    definition = 'De mogelijke letters en cijfers voor een letter- of cijfermarkering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLetterCijfer'
    options = {
        '-': KeuzelijstWaarde(invulwaarde='-',
                              label='-',
                              status='ingebruik',
                              definitie='Koppelteken.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/-'),
        '0': KeuzelijstWaarde(invulwaarde='0',
                              label='0',
                              status='ingebruik',
                              definitie='Cijfer 0.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/0'),
        '1': KeuzelijstWaarde(invulwaarde='1',
                              label='1',
                              status='ingebruik',
                              definitie='Cijfer 1.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/1'),
        '2': KeuzelijstWaarde(invulwaarde='2',
                              label='2',
                              status='ingebruik',
                              definitie='Cijfer 2.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/2'),
        '3': KeuzelijstWaarde(invulwaarde='3',
                              label='3',
                              status='ingebruik',
                              definitie='Cijfer 3.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/3'),
        '4': KeuzelijstWaarde(invulwaarde='4',
                              label='4',
                              status='ingebruik',
                              definitie='Cijfer 4.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/4'),
        '5': KeuzelijstWaarde(invulwaarde='5',
                              label='5',
                              status='ingebruik',
                              definitie='Cijfer 5.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/5'),
        '6': KeuzelijstWaarde(invulwaarde='6',
                              label='6',
                              status='ingebruik',
                              definitie='Cijfer 6.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/6'),
        '7': KeuzelijstWaarde(invulwaarde='7',
                              label='7',
                              status='ingebruik',
                              definitie='Cijfer 7.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/7'),
        '8': KeuzelijstWaarde(invulwaarde='8',
                              label='8',
                              status='ingebruik',
                              definitie='Cijfer 8.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/8'),
        '9': KeuzelijstWaarde(invulwaarde='9',
                              label='9',
                              status='ingebruik',
                              definitie='Cijfer 9.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/9'),
        'a': KeuzelijstWaarde(invulwaarde='a',
                              label='a',
                              status='ingebruik',
                              definitie='Letter a.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/a'),
        'b': KeuzelijstWaarde(invulwaarde='b',
                              label='b',
                              status='ingebruik',
                              definitie='Letter b.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/b'),
        'c': KeuzelijstWaarde(invulwaarde='c',
                              label='c',
                              status='ingebruik',
                              definitie='Letter c.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/c'),
        'd': KeuzelijstWaarde(invulwaarde='d',
                              label='d',
                              status='ingebruik',
                              definitie='Letter d.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/d'),
        'e': KeuzelijstWaarde(invulwaarde='e',
                              label='e',
                              status='ingebruik',
                              definitie='Letter e.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/e'),
        'f': KeuzelijstWaarde(invulwaarde='f',
                              label='f',
                              status='ingebruik',
                              definitie='Letter f.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/f'),
        'g': KeuzelijstWaarde(invulwaarde='g',
                              label='g',
                              status='ingebruik',
                              definitie='Letter g.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/g'),
        'h': KeuzelijstWaarde(invulwaarde='h',
                              label='h',
                              status='ingebruik',
                              definitie='Letter h.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/h'),
        'i': KeuzelijstWaarde(invulwaarde='i',
                              label='i',
                              status='ingebruik',
                              definitie='Letter i.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/i'),
        'j': KeuzelijstWaarde(invulwaarde='j',
                              label='j',
                              status='ingebruik',
                              definitie='Letter j.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/j'),
        'k': KeuzelijstWaarde(invulwaarde='k',
                              label='k',
                              status='ingebruik',
                              definitie='Letter k.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/k'),
        'l': KeuzelijstWaarde(invulwaarde='l',
                              label='l',
                              status='ingebruik',
                              definitie='Letter l.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/l'),
        'm': KeuzelijstWaarde(invulwaarde='m',
                              label='m',
                              status='ingebruik',
                              definitie='Letter m.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/m'),
        'n': KeuzelijstWaarde(invulwaarde='n',
                              label='n',
                              status='ingebruik',
                              definitie='Letter n.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/n'),
        'o': KeuzelijstWaarde(invulwaarde='o',
                              label='o',
                              status='ingebruik',
                              definitie='Letter o.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/o'),
        'p': KeuzelijstWaarde(invulwaarde='p',
                              label='p',
                              status='ingebruik',
                              definitie='Letter p.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/p'),
        'q': KeuzelijstWaarde(invulwaarde='q',
                              label='q',
                              status='ingebruik',
                              definitie='Letter q.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/q'),
        'r': KeuzelijstWaarde(invulwaarde='r',
                              label='r',
                              status='ingebruik',
                              definitie='Letter r.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/r'),
        's': KeuzelijstWaarde(invulwaarde='s',
                              label='s',
                              status='ingebruik',
                              definitie='Letter s.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/s'),
        't': KeuzelijstWaarde(invulwaarde='t',
                              label='t',
                              status='ingebruik',
                              definitie='Letter t.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/t'),
        'u': KeuzelijstWaarde(invulwaarde='u',
                              label='u',
                              status='ingebruik',
                              definitie='Letter u.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/u'),
        'v': KeuzelijstWaarde(invulwaarde='v',
                              label='v',
                              status='ingebruik',
                              definitie='Letter v.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/v'),
        'w': KeuzelijstWaarde(invulwaarde='w',
                              label='w',
                              status='ingebruik',
                              definitie='Letter w.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/w'),
        'x': KeuzelijstWaarde(invulwaarde='x',
                              label='x',
                              status='ingebruik',
                              definitie='Letter x.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/x'),
        'y': KeuzelijstWaarde(invulwaarde='y',
                              label='y',
                              status='ingebruik',
                              definitie='Letter y.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/y'),
        'z': KeuzelijstWaarde(invulwaarde='z',
                              label='z',
                              status='ingebruik',
                              definitie='Letter z.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/z'),
        'â': KeuzelijstWaarde(invulwaarde='â',
                              label='â',
                              status='ingebruik',
                              definitie='Letter â.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/â'),
        'é': KeuzelijstWaarde(invulwaarde='é',
                              label='é',
                              status='ingebruik',
                              definitie='Letter é.',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLetterCijfer/é')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMateriaalLadder(KeuzelijstField):
    """Het materiaal waaruit de ladder is opgebouwd."""
    naam = 'KlMateriaalLadder'
    label = 'Materiaal ladder'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMateriaalLadder'
    definition = 'Het materiaal waaruit de ladder is opgebouwd.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMateriaalLadder'
    options = {
        'hout': KeuzelijstWaarde(invulwaarde='hout',
                                 label='Hout',
                                 status='ingebruik',
                                 definitie='De ladder is gemaakt in hout.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalLadder/hout'),
        'kunststof': KeuzelijstWaarde(invulwaarde='kunststof',
                                      label='Kunststof',
                                      status='ingebruik',
                                      definitie='De ladder is gemaakt in kunststof.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalLadder/kunststof'),
        'metaal': KeuzelijstWaarde(invulwaarde='metaal',
                                   label='Metaal',
                                   status='ingebruik',
                                   definitie='De ladder is gemaakt in metaal.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMateriaalLadder/metaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlAflsuitingType import KlAflsuitingType
from otlmow_model.Datatypes.KlAfsluitingMateriaal import KlAfsluitingMateriaal
from otlmow_model.Datatypes.KlAfsluitingMerk import KlAfsluitingMerk
from otlmow_model.Datatypes.KlAfsluitingModelnaam import KlAfsluitingModelnaam
from otlmow_model.Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Afsluiting(AIMObject, LijnGeometrie):
    """Op het terrein ondubbelzinnig aanwijsbare en permanent verankerde scheiding."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        LijnGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactpunt')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aswegersite')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Zoutbijlaadplaats')

        self._hoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting.hoogte',
                                    definition='De hoogte in centimeter van de afsluiting.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlAfsluitingMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting.materiaal',
                                       definition='Het materiaal waaruit de afsluiting vervaardigd is.',
                                       owner=self)

        self._merk = OTLAttribuut(field=KlAfsluitingMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting.merk',
                                  definition='Het merk van de afsluiting.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlAfsluitingModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting.modelnaam',
                                       definition='De modelnaam van de afsluiting.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting.technischeFiche',
                                             definition='De technische fiche van de afsluiting.',
                                             owner=self)

        self._type = OTLAttribuut(field=KlAflsuitingType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting.type',
                                  definition='Het type van afsluiting.',
                                  owner=self)

    @property
    def hoogte(self) -> KwantWrdInCentimeterWaarden:
        """De hoogte in centimeter van de afsluiting."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de afsluiting vervaardigd is."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de afsluiting."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de afsluiting."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de afsluiting."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van afsluiting."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeBetonnenProfiel(KeuzelijstField):
    """Het type betonnen profiel."""
    naam = 'KlTypeBetonnenProfiel'
    label = 'Type betonnen profiel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTypeBetonnenProfiel'
    definition = 'Het type betonnen profiel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeBetonnenProfiel'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='Andere',
                                   status='ingebruik',
                                   definitie='Niet-standaardprofiel: een profiel in een andere, specifieke vorm.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/andere'),
        'i-profiel': KeuzelijstWaarde(invulwaarde='i-profiel',
                                      label='I-profiel',
                                      status='ingebruik',
                                      definitie='Standaardprofiel met een dwarsdoorsnede in de vorm van een I (onder- en bovenflens die met elkaar verbonden zijn door het lijf).',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/i-profiel'),
        'omgekeerd-t-profiel': KeuzelijstWaarde(invulwaarde='omgekeerd-t-profiel',
                                                label='Omgekeerd T-profiel',
                                                status='ingebruik',
                                                definitie='Standaardprofiel met een dwarsdoorsnede in de vorm van een T (geen bovenfles, wel een onderflens en een lijf).',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/omgekeerd-t-profiel'),
        'omgekeerd-u-profiel': KeuzelijstWaarde(invulwaarde='omgekeerd-u-profiel',
                                                label='Omgekeerd U-profiel',
                                                status='ingebruik',
                                                definitie='Standaardprofiel met een bovenflens en twee lijven die samen een omgekeerde U vormen.',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/omgekeerd-u-profiel'),
        'plaatligger': KeuzelijstWaarde(invulwaarde='plaatligger',
                                        label='Plaatligger',
                                        status='ingebruik',
                                        definitie='Standaardprofiel met een dwarsdoorsnede in de vorm van een I (onder- en bovenflens die met elkaar verbonden zijn door het lijf) maar de bovenflens is verbreed.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/plaatligger'),
        'rechthoekige-ligger': KeuzelijstWaarde(invulwaarde='rechthoekige-ligger',
                                                label='Rechthoekige ligger',
                                                status='ingebruik',
                                                definitie='Niet-standaardprofiel met een dwarsdoorsnede van een rechthoek (massieve ligger).',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/rechthoekige-ligger'),
        'u-profiel': KeuzelijstWaarde(invulwaarde='u-profiel',
                                      label='U-profiel',
                                      status='ingebruik',
                                      definitie='Standaardprofiel met een onderflens en twee lijven die samen een U vormen.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/u-profiel'),
        'z-profiel': KeuzelijstWaarde(invulwaarde='z-profiel',
                                      label='Z-profiel',
                                      status='ingebruik',
                                      definitie='Niet-standaardprofiel met een dwarsdoorsnede in de vorm van een Z.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBetonnenProfiel/z-profiel')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlKamerKlasse(KeuzelijstField):
    """De stabiliteitsklasse van de kamer."""
    naam = 'KlKamerKlasse'
    label = 'Kamer klasse'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlKamerKlasse'
    definition = 'De stabiliteitsklasse van de kamer.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlKamerKlasse'
    options = {
        'klasse-1': KeuzelijstWaarde(invulwaarde='klasse-1',
                                     label='klasse 1',
                                     status='ingebruik',
                                     definitie='klasse 1',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKamerKlasse/klasse-1'),
        'klasse-2': KeuzelijstWaarde(invulwaarde='klasse-2',
                                     label='klasse 2',
                                     status='ingebruik',
                                     definitie='klasse 2',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlKamerKlasse/klasse-2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcAfmetingDiameterInCmWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._diameter = OTLAttribuut(field=KwantWrdInCentimeter,
                                      naam='diameter',
                                      label='diameter',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcAfmetingDiameterInCm.diameter',
                                      definition='De diameter in centimeter.',
                                      owner=self)

    @property
    def diameter(self) -> KwantWrdInCentimeterWaarden:
        """De diameter in centimeter."""
        return self._diameter.get_waarde()

    @diameter.setter
    def diameter(self, value):
        self._diameter.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcAfmetingDiameterInCm(ComplexField):
    """Complex datatype voor de afmeting van een diameter in centimeter."""
    naam = 'DtcAfmetingDiameterInCm'
    label = 'Afmeting diameter in centimeter'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcAfmetingDiameterInCm'
    definition = 'Complex datatype voor de afmeting van een diameter in centimeter.'
    waardeObject = DtcAfmetingDiameterInCmWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEGCSchermtype(KeuzelijstField):
    """De mogelijke schermtypes (vlak, niet-vlak)."""
    naam = 'KlLEGCSchermtype'
    label = 'Schermtype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEGCSchermtype'
    definition = 'De mogelijke schermtypes (vlak, niet-vlak).'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEGCSchermtype'
    options = {
        'niet-vlak': KeuzelijstWaarde(invulwaarde='niet-vlak',
                                      label='niet-vlak',
                                      status='ingebruik',
                                      definitie='De niet-vlakke schermen zijn de schermen die niet kunnen getest worden volgens de normen NBN EN 1793-1 NBN EN 1793-2.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCSchermtype/niet-vlak'),
        'vlak': KeuzelijstWaarde(invulwaarde='vlak',
                                 label='vlak',
                                 status='ingebruik',
                                 definitie='De vlakke schermen zijn de schermen die kunnen getest worden volgens de normen NBN EN 1793-1 NBN EN 1793-2.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCSchermtype/vlak')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlVormAanleveringHoutigeVegetatie(KeuzelijstField):
    """De wijze waarop het plantgoed wordt aangeleverd."""
    naam = 'KlVormAanleveringHoutigeVegetatie'
    label = 'Vorm aanlevering houtige vegetatie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlVormAanleveringHoutigeVegetatie'
    definition = 'De wijze waarop het plantgoed wordt aangeleverd.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlVormAanleveringHoutigeVegetatie'
    options = {
        'bomen': KeuzelijstWaarde(invulwaarde='bomen',
                                  label='bomen',
                                  status='ingebruik',
                                  definitie='Aanlevering van houtige vegetatie in de vorm van bomen.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVormAanleveringHoutigeVegetatie/bomen'),
        'bosgoed': KeuzelijstWaarde(invulwaarde='bosgoed',
                                    label='bosgoed',
                                    status='ingebruik',
                                    definitie='Aanlevering van houtige vegetatie in de vorm van bosgoed.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVormAanleveringHoutigeVegetatie/bosgoed'),
        'meerstammige-bomen': KeuzelijstWaarde(invulwaarde='meerstammige-bomen',
                                               label='meerstammige bomen',
                                               status='ingebruik',
                                               definitie='Aanlevering van houtige vegetatie in de vorm van meerstammige bomen.',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVormAanleveringHoutigeVegetatie/meerstammige-bomen'),
        'poten': KeuzelijstWaarde(invulwaarde='poten',
                                  label='poten',
                                  status='ingebruik',
                                  definitie='Aanlevering van houtige vegetatie in de vorm van poten.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVormAanleveringHoutigeVegetatie/poten'),
        'veer': KeuzelijstWaarde(invulwaarde='veer',
                                 label='veer',
                                 status='ingebruik',
                                 definitie='Aanlevering van houtige vegetatie in de vorm van veer.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlVormAanleveringHoutigeVegetatie/veer')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWegbebakeningType(KeuzelijstField):
    """De vormen van wegbebakening."""
    naam = 'KlWegbebakeningType'
    label = 'Wegbebakening type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWegbebakeningType'
    definition = 'De vormen van wegbebakening.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWegbebakeningType'
    options = {
        'type-1-(new-jersey-reclip)': KeuzelijstWaarde(invulwaarde='type-1-(new-jersey-reclip)',
                                                       label='type 1 (new jersey reclip)',
                                                       status='ingebruik',
                                                       definitie='type 1 (new jersey reclip)',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbebakeningType/type-1-(new-jersey-reclip)'),
        'type-2-(new-jersey)': KeuzelijstWaarde(invulwaarde='type-2-(new-jersey)',
                                                label='type 2 (new jersey)',
                                                status='ingebruik',
                                                definitie='type 2 (new jersey)',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbebakeningType/type-2-(new-jersey)'),
        'type-3-(referentiepaal)': KeuzelijstWaarde(invulwaarde='type-3-(referentiepaal)',
                                                    label='type 3 (referentiepaal)',
                                                    status='ingebruik',
                                                    definitie='type 3 (referentiepaal)',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbebakeningType/type-3-(referentiepaal)'),
        'type-A-(vangrail-reclip)': KeuzelijstWaarde(invulwaarde='type-A-(vangrail-reclip)',
                                                     label='type A (vangrail reclip)',
                                                     status='ingebruik',
                                                     definitie='type A (vangrail reclip)',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbebakeningType/type-A-(vangrail-reclip)'),
        'type-B-(vangrail)': KeuzelijstWaarde(invulwaarde='type-B-(vangrail)',
                                              label='type B (vangrail)',
                                              status='ingebruik',
                                              definitie='type B (vangrail)',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbebakeningType/type-B-(vangrail)'),
        'type-C-(vangrail-trapezium)': KeuzelijstWaarde(invulwaarde='type-C-(vangrail-trapezium)',
                                                        label='type C (vangrail trapezium)',
                                                        status='ingebruik',
                                                        definitie='Type C (vangrail trapezium)',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWegbebakeningType/type-C-(vangrail-trapezium)')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBoogpaalType(KeuzelijstField):
    """Draagwijdte van de boogpaal."""
    naam = 'KlBoogpaalType'
    label = 'Type boogpaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBoogpaalType'
    definition = 'Draagwijdte van de boogpaal.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBoogpaalType'
    options = {
        '3.50': KeuzelijstWaarde(invulwaarde='3.50',
                                 label='3.50',
                                 status='ingebruik',
                                 definitie='middelgrote draagwijdte',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoogpaalType/3.50'),
        '7.50': KeuzelijstWaarde(invulwaarde='7.50',
                                 label='7.50',
                                 status='ingebruik',
                                 definitie='grote draagwijdte',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBoogpaalType/7.50')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWeegsensorType(KeuzelijstField):
    """Het type van de weegsensor."""
    naam = 'KlWeegsensorType'
    label = 'Weegsensor type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWeegsensorType'
    definition = 'Het type van de weegsensor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWeegsensorType'
    options = {
        'piëzo-kwarts': KeuzelijstWaarde(invulwaarde='piëzo-kwarts',
                                         label='piëzo-kwarts',
                                         status='ingebruik',
                                         definitie='piëzo-kwarts',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWeegsensorType/piëzo-kwarts')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class BekledingComponent(AIMObject):
    """Abstracte voor componenten die als bekleding worden bevestigd op andere elementen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Luchtkwaliteittoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aanstraalverlichting')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Antenne')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Codeklavier')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingsverlichting')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#InwendigVerlichtPictogram')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Luidspreker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Meetmicrofoon')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WVConsole')



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Verlichtingstoestel import Verlichtingstoestel
from otlmow_model.Classes.Abstracten.VerlichtingstoestelConnector import VerlichtingstoestelConnector
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DteKleurRAL import DteKleurRAL, DteKleurRALWaarden
from otlmow_model.Datatypes.KlArmatuurkleur import KlArmatuurkleur
from otlmow_model.Datatypes.KlWvLedAantalTeVerlichtenRijstroken import KlWvLedAantalTeVerlichtenRijstroken
from otlmow_model.Datatypes.KlWvLedKleurTemp import KlWvLedKleurTemp
from otlmow_model.Datatypes.KlWvLedLichtkleur import KlWvLedLichtkleur
from otlmow_model.Datatypes.KlWvLedLichtpunthoogte import KlWvLedLichtpunthoogte
from otlmow_model.Datatypes.KlWvLedOverhang import KlWvLedOverhang
from otlmow_model.Datatypes.KlWvLedProtector import KlWvLedProtector
from otlmow_model.Datatypes.KlWvLedTussenafstand import KlWvLedTussenafstand
from otlmow_model.Datatypes.KlWvLedVerlNiveau import KlWvLedVerlNiveau
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class VerlichtingstoestelLED(Verlichtingstoestel, VerlichtingstoestelConnector):
    """Het geheel van de LEDlichtmodule en de behuizing die werden samengesteld met als doel: * de lichtstroom van de lichtbronnen hoofdzakelijk op het te verlichten oppervlak (doorlopende wegsectie, conflictgebied,...) te richten, teneinde de zichtbaarheid te verhogen; * de lichtstroom te beheersen zodat de weggebruikers niet verblind worden en de lichthinder beperkt wordt; * het optisch systeem, de lichtbronnen en de hulpapparatuur tegen uitwendige invloeden te beschermen De LED driver bevindt zich fysiek in het verlichtingstoestel maar wordt als een apart onderdeel behandeld."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Verlichtingstoestel.__init__(self)
        VerlichtingstoestelConnector.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EMDraagconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleideconstructie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LEDDriver')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LEDDriver')

        self._aantalTeVerlichtenRijstroken = OTLAttribuut(field=KlWvLedAantalTeVerlichtenRijstroken,
                                                          naam='aantalTeVerlichtenRijstroken',
                                                          label='aantal te verlichten rijstroken',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.aantalTeVerlichtenRijstroken',
                                                          definition='Het aantal rijstroken dat verlicht wordt door het LED verlichtingstoestel.',
                                                          owner=self)

        self._armatuurkleur = OTLAttribuut(field=DteKleurRAL,
                                           naam='armatuurkleur',
                                           label='armatuurkleur',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.armatuurkleur',
                                           usagenote='Attribuut uit gebruik sinds versie 2.3.0 ',
                                           deprecated_version='2.3.0',
                                           definition='De kleur van de zichtbare buitenkant van het verlichtingstoestel.',
                                           owner=self)

        self._heeftAntiVandalisme = OTLAttribuut(field=BooleanField,
                                                 naam='heeftAntiVandalisme',
                                                 label='heeft anti vandalisme',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.heeftAntiVandalisme',
                                                 definition='Is het een antivandalisme type verlichtingstoestel?',
                                                 owner=self)

        self._isFaunavriendelijk = OTLAttribuut(field=BooleanField,
                                                naam='isFaunavriendelijk',
                                                label='is faunavriendelijk',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.isFaunavriendelijk',
                                                definition='Geeft aan of de lichtkleur van de verlichting is aangepast (gebruik van oranje/rode/amberkleur ipv wit licht) zodat deze als minder storend wordt ervaren door fauna zoals bijvoorbeeld vleermuizen.',
                                                owner=self)

        self._isLijnvormig = OTLAttribuut(field=BooleanField,
                                          naam='isLijnvormig',
                                          label='is lijnvormig',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.isLijnvormig',
                                          definition='Is de led verlichting lijnvormig, bv. een led-strip?',
                                          owner=self)

        self._kleurArmatuur = OTLAttribuut(field=KlArmatuurkleur,
                                           naam='kleurArmatuur',
                                           label='kleur armatuur',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.kleurArmatuur',
                                           definition='De kleur van de zichtbare buitenkant van het verlichtingstoestel.',
                                           owner=self)

        self._kleurTemperatuur = OTLAttribuut(field=KlWvLedKleurTemp,
                                              naam='kleurTemperatuur',
                                              label='kleur temperatuur',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.kleurTemperatuur',
                                              definition="Kleurtemperatuur van de LED's.",
                                              owner=self)

        self._lichtkleur = OTLAttribuut(field=KlWvLedLichtkleur,
                                        naam='lichtkleur',
                                        label='lichtkleur',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.lichtkleur',
                                        definition='Beschrijving van de kleur van het licht adhv de naam van de kleur.',
                                        owner=self)

        self._lichtpuntHoogte = OTLAttribuut(field=KlWvLedLichtpunthoogte,
                                             naam='lichtpuntHoogte',
                                             label='lichtpunt hoogte',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.lichtpuntHoogte',
                                             definition='Hoogte van het lichtpunt ten opzichte van de rijweg.',
                                             owner=self)

        self._overhang = OTLAttribuut(field=KlWvLedOverhang,
                                      naam='overhang',
                                      label='overhang',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.overhang',
                                      definition='Afstand tot de rand van de rijbaan van de verticale projectie van het verlichtingstoestel op de rijbaan in meter. Als de afstand tot de rijbaan gelijk is aan 0, dan valt de verticale projectie samen met de rand van de rijbaan, bij negatieve waardes ligt de verticale projectie in de berm en bij positieve waardes ligt de verticale projectie op de rijbaan',
                                      owner=self)

        self._protector = OTLAttribuut(field=KlWvLedProtector,
                                       naam='protector',
                                       label='protector',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.protector',
                                       definition="Type doorschijnende kap ter bescherming van de LED's (vlak glas, polycarbonaat,...).",
                                       owner=self)

        self._tussenAfstand = OTLAttribuut(field=KlWvLedTussenafstand,
                                           naam='tussenAfstand',
                                           label='tussen afstand',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.tussenAfstand',
                                           usagenote='Attribuut uit gebruik sinds versie 2.4.0 ',
                                           deprecated_version='2.4.0',
                                           definition='Afstand tussen de verschillende LED verlichtingstoestellen.',
                                           owner=self)

        self._tussenafstandLED = OTLAttribuut(field=KwantWrdInMeter,
                                              naam='tussenafstandLED',
                                              label='tussenafstand LED',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.tussenafstandLED',
                                              usagenote='Maximum 1 cijfer na de komma ingeven.',
                                              definition='Afstand, uitgedrukt in meter, tussen de verschillende LED verlichtingstoestellen.',
                                              owner=self)

        self._verlichtingsNiveau = OTLAttribuut(field=KlWvLedVerlNiveau,
                                                naam='verlichtingsNiveau',
                                                label='verlichtings niveau',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED.verlichtingsNiveau',
                                                definition='Een set van verlichtingstechnische eisen zoals gemiddelde luminantie, verlichtingssterkte, uniformiteiten.',
                                                owner=self)

    @property
    def aantalTeVerlichtenRijstroken(self) -> str:
        """Het aantal rijstroken dat verlicht wordt door het LED verlichtingstoestel."""
        return self._aantalTeVerlichtenRijstroken.get_waarde()

    @aantalTeVerlichtenRijstroken.setter
    def aantalTeVerlichtenRijstroken(self, value):
        self._aantalTeVerlichtenRijstroken.set_waarde(value, owner=self)

    @property
    def armatuurkleur(self) -> DteKleurRALWaarden:
        """De kleur van de zichtbare buitenkant van het verlichtingstoestel."""
        return self._armatuurkleur.get_waarde()

    @armatuurkleur.setter
    def armatuurkleur(self, value):
        self._armatuurkleur.set_waarde(value, owner=self)

    @property
    def heeftAntiVandalisme(self) -> bool:
        """Is het een antivandalisme type verlichtingstoestel?"""
        return self._heeftAntiVandalisme.get_waarde()

    @heeftAntiVandalisme.setter
    def heeftAntiVandalisme(self, value):
        self._heeftAntiVandalisme.set_waarde(value, owner=self)

    @property
    def isFaunavriendelijk(self) -> bool:
        """Geeft aan of de lichtkleur van de verlichting is aangepast (gebruik van oranje/rode/amberkleur ipv wit licht) zodat deze als minder storend wordt ervaren door fauna zoals bijvoorbeeld vleermuizen."""
        return self._isFaunavriendelijk.get_waarde()

    @isFaunavriendelijk.setter
    def isFaunavriendelijk(self, value):
        self._isFaunavriendelijk.set_waarde(value, owner=self)

    @property
    def isLijnvormig(self) -> bool:
        """Is de led verlichting lijnvormig, bv. een led-strip?"""
        return self._isLijnvormig.get_waarde()

    @isLijnvormig.setter
    def isLijnvormig(self, value):
        self._isLijnvormig.set_waarde(value, owner=self)

    @property
    def kleurArmatuur(self) -> str:
        """De kleur van de zichtbare buitenkant van het verlichtingstoestel."""
        return self._kleurArmatuur.get_waarde()

    @kleurArmatuur.setter
    def kleurArmatuur(self, value):
        self._kleurArmatuur.set_waarde(value, owner=self)

    @property
    def kleurTemperatuur(self) -> str:
        """Kleurtemperatuur van de LED's."""
        return self._kleurTemperatuur.get_waarde()

    @kleurTemperatuur.setter
    def kleurTemperatuur(self, value):
        self._kleurTemperatuur.set_waarde(value, owner=self)

    @property
    def lichtkleur(self) -> str:
        """Beschrijving van de kleur van het licht adhv de naam van de kleur."""
        return self._lichtkleur.get_waarde()

    @lichtkleur.setter
    def lichtkleur(self, value):
        self._lichtkleur.set_waarde(value, owner=self)

    @property
    def lichtpuntHoogte(self) -> str:
        """Hoogte van het lichtpunt ten opzichte van de rijweg."""
        return self._lichtpuntHoogte.get_waarde()

    @lichtpuntHoogte.setter
    def lichtpuntHoogte(self, value):
        self._lichtpuntHoogte.set_waarde(value, owner=self)

    @property
    def overhang(self) -> str:
        """Afstand tot de rand van de rijbaan van de verticale projectie van het verlichtingstoestel op de rijbaan in meter. Als de afstand tot de rijbaan gelijk is aan 0, dan valt de verticale projectie samen met de rand van de rijbaan, bij negatieve waardes ligt de verticale projectie in de berm en bij positieve waardes ligt de verticale projectie op de rijbaan"""
        return self._overhang.get_waarde()

    @overhang.setter
    def overhang(self, value):
        self._overhang.set_waarde(value, owner=self)

    @property
    def protector(self) -> str:
        """Type doorschijnende kap ter bescherming van de LED's (vlak glas, polycarbonaat,...)."""
        return self._protector.get_waarde()

    @protector.setter
    def protector(self, value):
        self._protector.set_waarde(value, owner=self)

    @property
    def tussenAfstand(self) -> str:
        """Afstand tussen de verschillende LED verlichtingstoestellen."""
        return self._tussenAfstand.get_waarde()

    @tussenAfstand.setter
    def tussenAfstand(self, value):
        self._tussenAfstand.set_waarde(value, owner=self)

    @property
    def tussenafstandLED(self) -> KwantWrdInMeterWaarden:
        """Afstand, uitgedrukt in meter, tussen de verschillende LED verlichtingstoestellen."""
        return self._tussenafstandLED.get_waarde()

    @tussenafstandLED.setter
    def tussenafstandLED(self, value):
        self._tussenafstandLED.set_waarde(value, owner=self)

    @property
    def verlichtingsNiveau(self) -> str:
        """Een set van verlichtingstechnische eisen zoals gemiddelde luminantie, verlichtingssterkte, uniformiteiten."""
        return self._verlichtingsNiveau.get_waarde()

    @verlichtingsNiveau.setter
    def verlichtingsNiveau(self, value):
        self._verlichtingsNiveau.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlGeleidingMateriaal(KeuzelijstField):
    """Materialen voor de geleidingwand om kleinere wilde dieren te geleiden."""
    naam = 'KlGeleidingMateriaal'
    label = 'Geleiding materiaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlGeleidingMateriaal'
    definition = 'Materialen voor de geleidingwand om kleinere wilde dieren te geleiden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlGeleidingMateriaal'
    options = {
        'beton': KeuzelijstWaarde(invulwaarde='beton',
                                  label='beton',
                                  status='ingebruik',
                                  definitie='Geleiding bestaande uit een betonnen wand.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeleidingMateriaal/beton'),
        'kunststof': KeuzelijstWaarde(invulwaarde='kunststof',
                                      label='kunststof',
                                      status='ingebruik',
                                      definitie='Geleiding bestaande uit een kunststoffen wand.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeleidingMateriaal/kunststof'),
        'metaal': KeuzelijstWaarde(invulwaarde='metaal',
                                   label='metaal',
                                   status='ingebruik',
                                   definitie='Geleiding bestaande uit een metalen wand.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlGeleidingMateriaal/metaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Onderdeel.BetonnenConstructieObject import BetonnenConstructieObject
from otlmow_model.Datatypes.KlDikteBetonnenPlaat import KlDikteBetonnenPlaat
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class BetonnenPlaat(BetonnenConstructieObject, VlakGeometrie):
    """Een vlak, plat betonnen enkelvoudig constructie-element."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenPlaat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        BetonnenConstructieObject.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')

        self._dikte = OTLAttribuut(field=KlDikteBetonnenPlaat,
                                   naam='dikte',
                                   label='dikte',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenPlaat.dikte',
                                   definition='De dikte van de betonnen plaat.',
                                   owner=self)

    @property
    def dikte(self) -> str:
        """De dikte van de betonnen plaat."""
        return self._dikte.get_waarde()

    @dikte.setter
    def dikte(self, value):
        self._dikte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlZonnepaneelMerk(KeuzelijstField):
    """Het merk van het zonnepaneel."""
    naam = 'KlZonnepaneelMerk'
    label = 'Zonnepaneel merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlZonnepaneelMerk'
    definition = 'Het merk van het zonnepaneel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlZonnepaneelMerk'
    options = {
        'solartronics': KeuzelijstWaarde(invulwaarde='solartronics',
                                         label='solartronics',
                                         status='ingebruik',
                                         definitie='solartronics ',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZonnepaneelMerk/solartronics')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.DtcBeschermingVraatschade import DtcBeschermingVraatschade, DtcBeschermingVraatschadeWaarden
from otlmow_model.Datatypes.KlBeschermingMaaischade import KlBeschermingMaaischade
from otlmow_model.Datatypes.KlMateriaalBeschermingVraatschade import KlMateriaalBeschermingVraatschade
from otlmow_model.Datatypes.KlPlantmaatHoogte import KlPlantmaatHoogte
from otlmow_model.Datatypes.KlPlantmaatOmtrek import KlPlantmaatOmtrek
from otlmow_model.Datatypes.KlVegetatiePlantverband import KlVegetatiePlantverband
from otlmow_model.Datatypes.KlVegetatieWortel import KlVegetatieWortel
from otlmow_model.Datatypes.KlVormAanleveringHoutigeVegetatie import KlVormAanleveringHoutigeVegetatie
from otlmow_model.BaseClasses.NonNegIntegerField import NonNegIntegerField


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcHoutigeAanlegWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._beschermingVraatschade = OTLAttribuut(field=DtcBeschermingVraatschade,
                                                    naam='beschermingVraatschade',
                                                    label='bescherming vraatschade',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.beschermingVraatschade',
                                                    usagenote='Attribuut uit gebruik sinds versie 2.0.0 ',
                                                    deprecated_version='2.0.0',
                                                    definition='Bescherming van de stam tegen knaagdieren.',
                                                    owner=self)

        self._heeftBoomplaat = OTLAttribuut(field=BooleanField,
                                            naam='heeftBoomplaat',
                                            label='heeft boomplaat',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.heeftBoomplaat',
                                            definition='Boomplaten worden aangebracht rond de stam van bomen, bosgoed en heesters en eventueel vastgezet met piketten. Ze hebben een centrale opening en een rechte snede, zodat ze op eenvoudige wijze rond de planten kunnen aangebracht worden.',
                                            owner=self)

        self._heeftHaagsteun = OTLAttribuut(field=BooleanField,
                                            naam='heeftHaagsteun',
                                            label='heeft haagsteun',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.heeftHaagsteun',
                                            definition='Duidt op de aanezigheid van een constructie van palen en bedrading die haagbeplanting ondersteunt.',
                                            owner=self)

        self._heeftWortelgeleidingwortelwering = OTLAttribuut(field=BooleanField,
                                                              naam='heeftWortelgeleidingwortelwering',
                                                              label='heeft wortelgeleiding-wortelwering',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.heeftWortelgeleidingwortelwering',
                                                              definition='Wortelgeleiding en –wering moet voorkomen dat boomwortels het trottoir, de middenberm, het fietspad, de rijweg, andere wegverhardingen en leidingstelsels beschadigen. Het heeft als doel om boomwortels naar beneden te leiden, waar ze onder een obstakel verder kunnen groeien.',
                                                              owner=self)

        self._maaischadeBescherming = OTLAttribuut(field=KlBeschermingMaaischade,
                                                   naam='maaischadeBescherming',
                                                   label='maaischade bescherming',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.maaischadeBescherming',
                                                   definition='Bescherming van de stam tegen maaimachines.',
                                                   owner=self)

        self._plantafstand = OTLAttribuut(field=NonNegIntegerField,
                                          naam='plantafstand',
                                          label='plantafstand',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.plantafstand',
                                          definition='Aantal planten per lopende meter.',
                                          owner=self)

        self._plantdichtheid = OTLAttribuut(field=NonNegIntegerField,
                                            naam='plantdichtheid',
                                            label='plantdichtheid',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.plantdichtheid',
                                            definition='Aantal planten per vierkante meter.',
                                            owner=self)

        self._plantmaatHoogte = OTLAttribuut(field=KlPlantmaatHoogte,
                                             naam='plantmaatHoogte',
                                             label='plantmaat hoogte',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.plantmaatHoogte',
                                             definition='De hoogte van de plant in cm gemeten tussen een minimum en maximum waarde.',
                                             owner=self)

        self._plantmaatOmtrek = OTLAttribuut(field=KlPlantmaatOmtrek,
                                             naam='plantmaatOmtrek',
                                             label='plantmaat omtrek',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.plantmaatOmtrek',
                                             definition='De stamomtrek in centimeter (gemeten op 1 m boven het maaiveld) met een minimum en maximum waarde.',
                                             owner=self)

        self._plantverband = OTLAttribuut(field=KlVegetatiePlantverband,
                                          naam='plantverband',
                                          label='plantverband',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.plantverband',
                                          definition='De wijze waarop de planten zijn geschikt.',
                                          owner=self)

        self._vormAanlevering = OTLAttribuut(field=KlVormAanleveringHoutigeVegetatie,
                                             naam='vormAanlevering',
                                             label='vorm aanlevering',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.vormAanlevering',
                                             definition='De wijze waarop het plantgoed wordt aangeleverd.',
                                             owner=self)

        self._vraatschadeBescherming = OTLAttribuut(field=KlMateriaalBeschermingVraatschade,
                                                    naam='vraatschadeBescherming',
                                                    label='vraatschade bescherming',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.vraatschadeBescherming',
                                                    definition='Bescherming van de stam tegen knaagdieren.',
                                                    owner=self)

        self._wortel = OTLAttribuut(field=KlVegetatieWortel,
                                    naam='wortel',
                                    label='wortel',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg.wortel',
                                    definition='De manier van levering en aanplanting van het wortelgestel van de boom of plant.',
                                    owner=self)

    @property
    def beschermingVraatschade(self) -> DtcBeschermingVraatschadeWaarden:
        """Bescherming van de stam tegen knaagdieren."""
        return self._beschermingVraatschade.get_waarde()

    @beschermingVraatschade.setter
    def beschermingVraatschade(self, value):
        self._beschermingVraatschade.set_waarde(value, owner=self._parent)

    @property
    def heeftBoomplaat(self) -> bool:
        """Boomplaten worden aangebracht rond de stam van bomen, bosgoed en heesters en eventueel vastgezet met piketten. Ze hebben een centrale opening en een rechte snede, zodat ze op eenvoudige wijze rond de planten kunnen aangebracht worden."""
        return self._heeftBoomplaat.get_waarde()

    @heeftBoomplaat.setter
    def heeftBoomplaat(self, value):
        self._heeftBoomplaat.set_waarde(value, owner=self._parent)

    @property
    def heeftHaagsteun(self) -> bool:
        """Duidt op de aanezigheid van een constructie van palen en bedrading die haagbeplanting ondersteunt."""
        return self._heeftHaagsteun.get_waarde()

    @heeftHaagsteun.setter
    def heeftHaagsteun(self, value):
        self._heeftHaagsteun.set_waarde(value, owner=self._parent)

    @property
    def heeftWortelgeleidingwortelwering(self) -> bool:
        """Wortelgeleiding en –wering moet voorkomen dat boomwortels het trottoir, de middenberm, het fietspad, de rijweg, andere wegverhardingen en leidingstelsels beschadigen. Het heeft als doel om boomwortels naar beneden te leiden, waar ze onder een obstakel verder kunnen groeien."""
        return self._heeftWortelgeleidingwortelwering.get_waarde()

    @heeftWortelgeleidingwortelwering.setter
    def heeftWortelgeleidingwortelwering(self, value):
        self._heeftWortelgeleidingwortelwering.set_waarde(value, owner=self._parent)

    @property
    def maaischadeBescherming(self) -> str:
        """Bescherming van de stam tegen maaimachines."""
        return self._maaischadeBescherming.get_waarde()

    @maaischadeBescherming.setter
    def maaischadeBescherming(self, value):
        self._maaischadeBescherming.set_waarde(value, owner=self._parent)

    @property
    def plantafstand(self) -> int:
        """Aantal planten per lopende meter."""
        return self._plantafstand.get_waarde()

    @plantafstand.setter
    def plantafstand(self, value):
        self._plantafstand.set_waarde(value, owner=self._parent)

    @property
    def plantdichtheid(self) -> int:
        """Aantal planten per vierkante meter."""
        return self._plantdichtheid.get_waarde()

    @plantdichtheid.setter
    def plantdichtheid(self, value):
        self._plantdichtheid.set_waarde(value, owner=self._parent)

    @property
    def plantmaatHoogte(self) -> str:
        """De hoogte van de plant in cm gemeten tussen een minimum en maximum waarde."""
        return self._plantmaatHoogte.get_waarde()

    @plantmaatHoogte.setter
    def plantmaatHoogte(self, value):
        self._plantmaatHoogte.set_waarde(value, owner=self._parent)

    @property
    def plantmaatOmtrek(self) -> str:
        """De stamomtrek in centimeter (gemeten op 1 m boven het maaiveld) met een minimum en maximum waarde."""
        return self._plantmaatOmtrek.get_waarde()

    @plantmaatOmtrek.setter
    def plantmaatOmtrek(self, value):
        self._plantmaatOmtrek.set_waarde(value, owner=self._parent)

    @property
    def plantverband(self) -> str:
        """De wijze waarop de planten zijn geschikt."""
        return self._plantverband.get_waarde()

    @plantverband.setter
    def plantverband(self, value):
        self._plantverband.set_waarde(value, owner=self._parent)

    @property
    def vormAanlevering(self) -> str:
        """De wijze waarop het plantgoed wordt aangeleverd."""
        return self._vormAanlevering.get_waarde()

    @vormAanlevering.setter
    def vormAanlevering(self, value):
        self._vormAanlevering.set_waarde(value, owner=self._parent)

    @property
    def vraatschadeBescherming(self) -> str:
        """Bescherming van de stam tegen knaagdieren."""
        return self._vraatschadeBescherming.get_waarde()

    @vraatschadeBescherming.setter
    def vraatschadeBescherming(self, value):
        self._vraatschadeBescherming.set_waarde(value, owner=self._parent)

    @property
    def wortel(self) -> str:
        """De manier van levering en aanplanting van het wortelgestel van de boom of plant."""
        return self._wortel.get_waarde()

    @wortel.setter
    def wortel(self, value):
        self._wortel.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcHoutigeAanleg(ComplexField):
    """Complex datatype dat de aanleg van houtige vegetatie beschrijft."""
    naam = 'DtcHoutigeAanleg'
    label = 'Houtige aanleg'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcHoutigeAanleg'
    definition = 'Complex datatype dat de aanleg van houtige vegetatie beschrijft.'
    waardeObject = DtcHoutigeAanlegWaarden

    def __str__(self):
        return ComplexField.__str__(self)

